/***************************************************************************
                          kbibiface.h  -  description
                             -------------------
    begin                : Sat Jun 7 2003
    copyright            : (C) 2003 by Thach Nguyen
    email                : thach.nguyen@rmit.edu.au
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KBIBIFACE_H
#define KBIBIFACE_H

#include <dcopobject.h>
#include <qstring.h>

/**
  *@author Thach Nguyen
  */

class KBibIface : virtual public DCOPObject
{
  K_DCOP
public:

k_dcop:
  virtual int insertFile(QString url, int fileType, bool notInsertExisting) = 0;
  virtual QString cite() = 0;
  virtual void setActive() = 0;
};

#endif
